local wave_texture = Resources.load_texture("firewave.png")
local wave_animation = "firewave.animation"

function card_init(player, props)
    local action = Action.new(player, "CHARACTER_THROW")
    action.on_execute_func = function(self, user)
        local hit_props = HitProps.new(
            props.damage,
            props.hit_flags,
            props.element,
            user:context(),
            Drag.None
        )
        self:add_anim_action(3, function()
            spawn_shockwave(player, player:get_tile(player:facing(), 1), player:facing(), hit_props)
        end)
    end
    return action
end

function spawn_shockwave(owner, tile, direction, props)
    local team = owner:team()
    local field = owner:field()
    local spawn_next
    spawn_next = function()
        if not tile:is_walkable() then return end
        -- Resources.play_audio(AudioType.Meteor)

        local spell = Spell.new(team)
        spell:set_facing(direction)
        spell:set_tile_highlight(Highlight.Solid)
        spell:set_hit_props(props)

        local sprite = spell:sprite()
        sprite:set_texture(wave_texture)
        sprite:set_layer(-1)

        local animation = spell:animation()
        animation:load(wave_animation)
        animation:set_state("DEFAULT")

        animation:on_frame(3, function()
            tile = tile:get_tile(direction, 1)
            spawn_next()
        end, true)
        animation:on_complete(function() spell:erase() end)

        spell.on_attack_func = function(self, other)
            owner:set_health(owner:health() + props.damage)
        end

        spell.on_update_func = function()
            spell:current_tile():attack_entities(spell)
        end

        field:spawn(spell, tile)
    end

    spawn_next()
end
